@@ -1,6 +1,10 @@
 import os
+from hashlib import sha256
 from pathlib import Path
+from time import time
 
+from pycpio.cpio.common import pad_cpio
+from pycpio.header import CPIOHeader
 from pycpio.masks import mode_bytes_from_path
 from zenlib.logging import loggify
 
@@ -40,22 +44,31 @@ class CPIOData:
             kwargs["name"] = str(path)
 
         data = []
-        data.append(CPIOData.from_path(path=path, relative=relative, *args, **kwargs))
+        top_kwargs = kwargs.copy()
+        top_kwargs["path"] = path
+        top_kwargs["relative"] = relative
+        data.append(CPIOData.from_path(*args, **top_kwargs))
         for child in path.iterdir():
+            child_kwargs = kwargs.copy()
+
             if parent:
                 child_path = parent / child
             else:
                 child_path = child
 
             if relative:
-                kwargs["name"] = str(child_path.relative_to(relative))
+                child_kwargs["name"] = str(child_path.relative_to(relative))
             else:
-                kwargs["name"] = str(child_path)
+                child_kwargs["name"] = str(child_path)
+
+            child_kwargs["path"] = child_path
+            child_kwargs["relative"] = relative
 
             if child.is_dir() and not child.is_symlink():
-                data.extend(CPIOData.from_dir(path=child_path, parent=parent, relative=relative, *args, **kwargs))
+                child_kwargs["parent"] = parent
+                data.extend(CPIOData.from_dir(*args, **child_kwargs))
             else:
-                data.append(CPIOData.from_path(path=child_path, relative=relative, *args, **kwargs))
+                data.append(CPIOData.from_path(*args, **child_kwargs))
         return data
 
     @staticmethod
@@ -70,7 +83,6 @@ class CPIOData:
 
         If absolute is set, the path is _allowed_ to be absolute, otherwise, the leading slash will be stripped.
         """
-        from pycpio.header import CPIOHeader
 
         path = Path(path)
         if logger := kwargs.get("logger"):
@@ -89,7 +101,6 @@ class CPIOData:
             if not path.exists():
                 raise ValueError("Path does not exist: %s" % path)
 
-        kwargs["path"] = path
         # If a name is provided, use it, otherwise, use the path, if relative is provided, use the relative path
         if name := kwargs.pop("name", None):
             kwargs["name"] = name
@@ -115,7 +126,7 @@ class CPIOData:
         kwargs["rdevminor"] = kwargs.pop("rdevminor", os.minor(path.stat(follow_symlinks=resolve_symlink).st_rdev))
 
         header = CPIOHeader(*args, **kwargs)
-        data = CPIOData.get_subtype(b"", header, *args, **kwargs)
+        data = CPIOData.get_subtype(b"", header, path=path, *args, **kwargs)
 
         if logger := kwargs.get("logger"):
             logger.debug(f"Created CPIO entry from path: {data}")
@@ -128,9 +139,6 @@ class CPIOData:
         Create a custom CPIO entry using names and args which are parsed by the header.
         Using the created header, the data type is determined and the appropriate object is returned.
         """
-        from time import time
-
-        from pycpio.header import CPIOHeader
 
         if logger := kwargs.get("logger"):
             logger.debug(f"Creating CPIO entry: {name}")
@@ -149,10 +157,10 @@ class CPIOData:
     def get_subtype(data: bytes, header, *args, **kwargs):
         """Get the appropriate subtype for the data based on the header mode type."""
         # Imports must be here so the module can be imported
-        from .chardev import CPIO_CharDev
-        from .dir import CPIO_Dir
-        from .file import CPIO_File
-        from .symlink import CPIO_Symlink
+        from pycpio.cpio.chardev import CPIO_CharDev
+        from pycpio.cpio.dir import CPIO_Dir
+        from pycpio.cpio.file import CPIO_File
+        from pycpio.cpio.symlink import CPIO_Symlink
 
         mode = header.mode_type
         logger = header.logger
@@ -182,8 +190,6 @@ class CPIOData:
         super().__setattr__(name, value)
         if name == "data":
             if value:
-                from hashlib import sha256
-
                 self.hash = sha256(value).hexdigest()
             self.header.filesize = len(value)
 
@@ -199,7 +205,6 @@ class CPIOData:
 
     def __bytes__(self):
         """Convert the data to bytes"""
-        from pycpio.cpio import pad_cpio
 
         payload = bytes(self.header) + self.data
         return payload + b"\x00" * pad_cpio(len(payload))
