@@ -1,12 +1,20 @@
+from datetime import datetime
+from grp import getgrnam
+from pwd import getpwnam
+
+from pycpio.cpio.common import pad_cpio
+from pycpio.header.header_funcs import get_header_from_magic, get_magic_from_header
+from pycpio.header.headers import HEADER_NEW
 from pycpio.masks import print_permissions, resolve_mode_bytes, resolve_permissions
-from zenlib.logging import loggify
+from zenlib.logging import LoggerMixIn
+from zenlib.util import colorize as c_
 
 
-@loggify
-class CPIOHeader:
+class CPIOHeader(LoggerMixIn):
     """CPIO HEADER, can be initialized from a segment of header data with or without a structure definition."""
 
     def __init__(self, header_data=b"", overrides={}, *args, **kwargs):
+        self.init_logger(args, kwargs)
         self.overrides = overrides
         if header_data:
             self.logger.debug("Creating CPIOEntry from header data: %s", header_data)
@@ -23,9 +31,6 @@ class CPIOHeader:
 
     def from_args(self, *args, **kwargs) -> None:
         """Initialize the object from the arguments."""
-        from .header_funcs import get_magic_from_header
-        from .headers import HEADER_NEW
-
         self.structure = kwargs.pop("structure", HEADER_NEW)
         self.name = kwargs.pop("name")
 
@@ -70,9 +75,6 @@ class CPIOHeader:
             try:
                 value = int(value)
             except ValueError:
-                from grp import getgrnam
-                from pwd import getpwnam
-
                 if key == "uid":
                     value = getpwnam(value).pw_uid
                 elif key == "gid":
@@ -93,12 +95,15 @@ class CPIOHeader:
             value = value.encode("ascii")
             self.logger.debug("[%s] %d bytes: %s" % (key, length, value))
 
+        # Log a warning if the filesize value changes and was not 0 before
         if key == "filesize" and value != b"00000000":
             if getattr(self, "filesize", b"00000000").lower() not in [value, b"00000000"]:
-                self.logger.warning("[%s] Changed filesize: %s -> %s" % (self.name, self.filesize, value))
+                self.logger.warning(f"[{c_(self.name, 'blue')}] Changed filesize: {c_(self.filesize, 'yellow')} -> {c_(value, 'green')}")
+        # Log a warning if the filesizes is set and is being cleared to 0, likely for a hardlink
         elif key == "filesize" and value == b"00000000":
             if getattr(self, "filesize", b"00000000") != b"00000000":
-                self.logger.warning("[%s] Setting filesize to 0" % self.name)
+                self.logger.info(f"[{c_(self.name, 'yellow')}] Setting filesize to 0")
+        # Log a warning if the inode is too large and must be set to 0 (to be recalculated if in an archive)
         elif key == "ino":
             if int(value, 16) > 0xFFFFFFFF:
                 self.logger.warning("Inode too large, setting to 0: %s" % value)
@@ -133,8 +138,9 @@ class CPIOHeader:
                 if hasattr(self, attribute):
                     self.logger.log(5, "[%s] Pre-override: %s" % (attribute, getattr(self, attribute)))
                 if attribute == "mode":
+                    mode = int(getattr(self, "mode", b"00000000"), 16)
                     # Mask the mode, then add the override
-                    value = (int(self.mode, 16) & 0o7777000) | (self.overrides[attribute] & 0o777)
+                    value = (mode & 0o7777000) | (self.overrides[attribute] & 0o777)
                 else:
                     value = self.overrides[attribute]
                 self.logger.debug("[%s] Setting override: %s" % (attribute, value))
@@ -143,13 +149,13 @@ class CPIOHeader:
     def _read_bytes(self, num_bytes: int) -> bytes:
         """Read the specified number of bytes from the data, incrementing the offset, then returning the data."""
         data = self.data[self.offset : self.offset + num_bytes]
-        self.logger.log(5, "Read %d bytes: %s" % (num_bytes, data))
+        self.logger.log(5, "Read %s bytes: %r" % (num_bytes, data))
         self.offset += num_bytes
         return data
 
     def add_data(self, data: bytes) -> None:
         """Add the file data to the object."""
-        self.logger.debug("Adding data: %s" % data)
+        self.logger.debug("Adding data: %r" % data)
         self.data += data
 
     def parse_header(self):
@@ -157,7 +163,6 @@ class CPIOHeader:
         Parse the data according to the structure.
         Sets attributes on the object.
         """
-        from .header_funcs import get_header_from_magic
 
         self.structure = get_header_from_magic(self.data[:6])
         for key, length in self.structure.items():
@@ -182,7 +187,6 @@ class CPIOHeader:
 
     def __bytes__(self):
         """Returns the bytes representation of the object."""
-        from pycpio.cpio import pad_cpio
 
         out_bytes = b""
         # Get the bytes for each attribute
@@ -197,7 +201,6 @@ class CPIOHeader:
 
     def __str__(self):
         """Returns a string representation of the object."""
-        from datetime import datetime
 
         out_str = f"[{int(self.ino, 16)}] "
         out_str += "Header:\n" if not hasattr(self, "name") else f"{self.name}:\n"
